{% extends 'base.html' %}
{% block title %}Confirm Deletion | {{ app_name|capfirst }}{% endblock %}
{% block content %}
<div class="container-lg">
  <div class="row justify-content-center">
    <div class="col-lg-6">
      <div class="card border-danger shadow-lg">
        <div class="card-header bg-danger text-white">
          <h2 class="h5 mb-0">
            <i class="fas fa-exclamation-triangle me-2"></i>
            Confirm Deletion
          </h2>
        </div>
        <div class="card-body">
          <p class="lead">Are you sure you want to delete "{{ object }}"?</p>
          <p class="text-muted">This action cannot be undone.</p>
        </div>
        <div class="card-footer bg-light">
          <form method="post">
            {% csrf_token %}
            <div class="d-flex justify-content-end gap-3">
              <a href="{% url '<< urls["list"] >>' %}" class="btn btn-secondary">
                <i class="fas fa-times me-2"></i> Cancel
              </a>
              <button type="submit" class="btn btn-danger">
                <i class="fas fa-trash me-2"></i> Confirm Delete
              </button>
            </div>
          </form>
        </div>
      </div>
    </div>
  </div>
</div>
{% endblock %}
