from django.contrib import admin
from .models import {{ model_name }}

@admin.register({{ model_name }})
class {{ model_name }}Admin(admin.ModelAdmin):
    list_display = [field.name for field in {{ model_name }}._meta.fields]
