{% extends 'base.html' %}
{% block title %}{{ model_name }} Detail | {{ app_name|capfirst }}{% endblock %}
{% block content %}
<div class="container-lg">
  <div class="row justify-content-center">
    <div class="col-lg-8">
      <div class="card shadow-sm">
        <div class="card-header bg-secondary text-white">
          <h2 class="h5 mb-0">{{ model_name }} Detail</h2>
        </div>
        <div class="card-body">
          <h3>{{ object.name }}</h3>
          <p>{{ object.description }}</p>
          <p><small>Created at: {{ object.created_at }}</small></p>
        </div>
        <div class="card-footer bg-light d-flex justify-content-between">
          <a href="{% url '<< urls["update"] >>' object.pk %}" class="btn btn-primary">
            <i class="fas fa-edit me-1"></i> Edit
          </a>
          <a href="{% url '<< urls["delete"] >>' object.pk %}" class="btn btn-danger">
            <i class="fas fa-trash-alt me-1"></i> Delete
          </a>
        </div>
      </div>
    </div>
  </div>
</div>
{% endblock %}
