<nav class="navbar navbar-expand-lg navbar-dark bg-dark sticky-top shadow-sm">
  <div class="container-fluid">
    <a class="navbar-brand" href="/" aria-label="BrandName Homepage">
      <i class="fas fa-rocket me-2"></i>
      <span class="brand-gradient">BrandName</span>
    </a>
    <button class="navbar-toggler" type="button"
            data-bs-toggle="collapse" data-bs-target="#mainNav"
            aria-controls="mainNav" aria-expanded="false"
            aria-label="Toggle navigation">
      <span class="navbar-toggler-icon"></span>
    </button>
    <div class="collapse navbar-collapse" id="mainNav">
      <ul class="navbar-nav me-auto mb-2 mb-lg-0">
        <li class="nav-item">
          <a class="nav-link active" href="/" aria-current="page">Home</a>
        </li>
        <li class="nav-item dropdown">
          <a class="nav-link dropdown-toggle" href="#" role="button"
             data-bs-toggle="dropdown" aria-expanded="false">
            Products
          </a>
          <ul class="dropdown-menu shadow">
            <li><a class="dropdown-item" href="#">All Products</a></li>
            <li><a class="dropdown-item" href="#">Categories</a></li>
            <li><hr class="dropdown-divider"></li>
            <li><a class="dropdown-item" href="#">New Arrivals</a></li>
          </ul>
        </li>
        <li class="nav-item">
          <a class="nav-link" href="#">About</a>
        </li>
        <li class="nav-item">
          <a class="nav-link" href="#">Contact</a>
        </li>
      </ul>
      <!-- Search Form -->
      <form class="d-flex me-3" role="search">
        <div class="input-group">
          <input type="search" class="form-control"
                 placeholder="Search..." aria-label="Search"
                 aria-describedby="search-button">
          <button class="btn btn-outline-light" type="submit" id="search-button">
            <i class="fas fa-search"></i>
          </button>
        </div>
      </form>
      <!-- Dark Mode Toggle & Account Dropdown -->
      <ul class="navbar-nav">
          <li class="nav-item">
              <button id="themeToggleBtn" class="btn" onclick="toggleTheme()">
                <i class="fas fa-moon"></i>
              </button>
          </li>
        <li class="nav-item dropdown">
          <a class="nav-link dropdown-toggle" href="#" role="button"
             data-bs-toggle="dropdown" aria-expanded="false"
             aria-label="Account menu">
            <i class="fas fa-user-circle me-1"></i>Account
          </a>
          <ul class="dropdown-menu dropdown-menu-end shadow">
            <li><a class="dropdown-item" href="#"><i class="fas fa-user me-2"></i>Profile</a></li>
            <li><a class="dropdown-item" href="#"><i class="fas fa-cog me-2"></i>Settings</a></li>
            <li><hr class="dropdown-divider"></li>
            <li><a class="dropdown-item text-danger" href="#"><i class="fas fa-sign-out-alt me-2"></i>Logout</a></li>
          </ul>
        </li>
      </ul>
    </div>
  </div>
</nav>
